@@ -711,4 +711,5 @@ art_dic = {
     "swim": "＿（ッ）>＿/／",
     "swim2": "ー（ッ）」",
     "swim3": "＿（ッ）へ",
-    "yawning": "＼(＾o＾)／"}
+    "yawning": "＼(＾o＾)／",
+    "bored": "╭∩╮<-L->╭∩╮"}
