@@ -6,7 +6,7 @@ from .data.fonts3 import *
 from .data.arts import *
 from .data.decorations import *
 
-ART_VERSION = "6.4"  # pragma: no cover
+ART_VERSION = "6.5"  # pragma: no cover
 FONT_SMALL_THRESHOLD = 50  # pragma: no cover
 FONT_MEDIUM_THRESHOLD = 100  # pragma: no cover
 FONT_LARGE_THRESHOLD = 200  # pragma: no cover
@@ -653,7 +653,8 @@ NON_ASCII_ARTS = [
     'swim2',
     'swim3',
     'yawning',
-    'boobs2']
+    'boobs2',
+    'bored']
 
 RANDOM_FILTERED_ARTS = [] + NON_ASCII_ARTS
 
@@ -959,7 +960,12 @@ NON_ASCII_FONTS = [
     "smila",
     "clay",
     "orinda",
-    "abby"
+    "abby",
+    "samya",
+    "veronika",
+    "hisoka",
+    "hideki",
+    "sunny"
 ]
 
 RANDOM_FILTERED_FONTS = [
@@ -1616,7 +1622,12 @@ FONT_MAP = {"block": [block_dic, True], "banner": [banner_dic, False],  # pragma
             "smila": [smila_dic, False],
             "clay": [clay_dic, False],
             "orinda": [orinda_dic, False],
-            "abby": [abby_dic, False]
+            "abby": [abby_dic, False],
+            "samya": [samya_dic, False],
+            "veronika": [veronika_dic, False],
+            "hisoka": [hisoka_dic, False],
+            "hideki": [hideki_dic, False],
+            "sunny": [sunny_dic, False]
             }
 
 DECORATIONS_MAP = {"angry1": angry1,  # pragma: no cover
