@@ -649,12 +649,18 @@ handwriting3 :
 hazy :
 ŤƐらŤ
 <BLANKLINE>
+hideki :
+丁乇丂丁
+<BLANKLINE>
 high_above :
 ᵗᵉˢᵗ
 <BLANKLINE>
 hippie :
 ⊥ε﹩⊥
 <BLANKLINE>
+hisoka :
+ｲ乇らｲ
+<BLANKLINE>
 hyves :
 t€$t
 <BLANKLINE>
@@ -760,6 +766,9 @@ TΞST
 russian2 :
 ƬƎƧƬ
 <BLANKLINE>
+samya :
+ꞎ୧𐒖ꞎ
+<BLANKLINE>
 sarah :
 ᏆℰЅᏆ
 <BLANKLINE>
@@ -829,6 +838,9 @@ subscript2 :
 sunday_cuddle :
 тєѕт
 <BLANKLINE>
+sunny :
+тḙṧт
+<BLANKLINE>
 superscript :
 ᵗᵉˢᵗ
 <BLANKLINE>
@@ -941,6 +953,9 @@ upside_down2 :
 vaporwave :
 ｔｅｓｔ
 <BLANKLINE>
+veronika :
+TᏋꚂT
+<BLANKLINE>
 vip :
 ƬΣƧƬ
 <BLANKLINE>
@@ -1101,6 +1116,9 @@ boombox1
 boombox2
 ♫♪ |̲̅̅●̲̅̅|̲̅̅=̲̅̅|̲̅̅●̲̅̅| ♫♪
 ******************************
+bored
+╭∩╮<-L->╭∩╮
+******************************
 boxing
 ლ(•́•́ლ)
 ******************************
